"use strict";
const command_1 = require("@oclif/command");
const path = require("path");
const json2csv_1 = require("json2csv");
const table = require("markdown-table");
const stringWidth = require("string-width");
const parsers_1 = require("./parsers");
class ParseSalesforceObject extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(ParseSalesforceObject);
        const props = [
            'label',
            'fullName',
            'type',
            'required',
        ];
        // parse sobject file
        // const Parser = args.path.includes('object-meta.xml') ? SourceFormatParser : MetadataFormatParser
        const rawFields = await parsers_1.parseSObjectFile(args.path);
        const dataList = [];
        for (const field of rawFields) {
            const data = {};
            for (const property of parsers_1.fieldProperties) {
                this.debug(field[property]);
                data[property] = field[property] ? field[property][0] : null;
            }
            dataList.push(data);
        }
        let result;
        switch (flags.format) {
            case 'soql': {
                const prefix = flags.namespace ? `${flags.namespace}__` : '';
                const objName = path.basename(args.path).split('.')[0];
                const fields = dataList.map(data => {
                    return `${prefix}${data.fullName}`;
                });
                result = [
                    'SELECT Id,',
                    fields.join(',\n'),
                    `FROM ${prefix}${objName}`,
                ].join('\n');
                break;
            }
            case 'csv':
                result = json2csv_1.parse(dataList, { fields: props });
                break;
            default:
                // markdown
                // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
                // @ts-ignore
                result = table([props, ...dataList.map(data => Object.values(data))], {
                    stringLength: stringWidth,
                });
        }
        this.log(result);
    }
}
// TODO
// static description = 'describe the command here'
ParseSalesforceObject.examples = [
    `$ parse-salesforce-object force-app/main/default/objects/Expense__c/Expense__c.object-meta.xml
| label       | fullName      | type     | required |
| ----------- | ------------- | -------- | -------- |
| Amount      | Amount__c     | Number   | false    |
| Client      | Client__c     | Text     | false    |
| Date        | Date__c       | DateTime | false    |
| Reimbursed? | Reimbursed__c | Checkbox |          |
`,
];
ParseSalesforceObject.flags = {
    // add --version flag to show CLI version
    version: command_1.flags.version({ char: 'v' }),
    // add --help flag to show CLI version
    help: command_1.flags.help({ char: 'h' }),
    format: command_1.flags.string({
        char: 'f',
        description: 'output format',
        options: ['markdown', 'csv', 'soql'],
        default: 'markdown',
    }),
    namespace: command_1.flags.string({
        char: 'n',
        description: 'namespace prefix (for SOQL format)',
    }),
};
ParseSalesforceObject.args = [{
        name: 'path',
        description: 'path to sObject file',
        required: true,
    }];
module.exports = ParseSalesforceObject;
